@@ -1,6 +1,7 @@
 from .enum import ResizeMethod, PaddingMethod, PaddingPosition
 from .pad import padding_video, padding_audio
 from .resize import resize_image, resize_video
+from tensorneko_util.preprocess import ffmpeg_available
 
 __all__ = [
     "ResizeMethod",
@@ -11,3 +12,8 @@ __all__ = [
     "resize_image",
     "resize_video"
 ]
+
+if ffmpeg_available:
+    from tensorneko_util.preprocess import video2frames
+    __all__.extend(["video2frames"])
+
